==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/id.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: id.php,v 1.14 2005/12/07 15:02:11 bigmichi1 Exp $
// Translated by: Firman Pribadi <http://ragiel.dhs.org>

$text['title']          = 'Informasi Sistem';

$text['vitals']         = 'Informasi Utama';
$text['hostname']       = 'Hostname Resmi';
$text['ip']             = 'IP Penerima';
$text['kversion']       = 'Versi Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Aktif Selama';
$text['users']          = 'Pengguna Saat Ini';
$text['loadavg']        = 'Beban Rata-rata';

$text['hardware']       = 'Informasi Perangkat Keras';
$text['numcpu']         = 'Prosesor';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Ukuran Cache';
$text['bogomips']       = 'Sistem Bogomips';

$text['pci']            = 'Perangkat PCI';
$text['ide']            = 'Perangkat IDE';
$text['scsi']           = 'Perangkat SCSI';
$text['usb']            = 'Perangkat USB';

$text['netusage']       = 'Status Penggunaan Jaringan';
$text['device']         = 'Perangkat';
$text['received']       = 'Diterima';
$text['sent']           = 'Dikirim';
$text['errors']         = 'Rusak/Drop';

$text['connections']    = 'Koneksi Jaringan Aktif';

$text['memusage']       = 'Status Penggunaan Memori';
$text['phymem']         = 'Memori Fisik';
$text['swap']           = 'Swap HardDisk';

$text['fs']             = 'Status Penggunaan Media Penyimpanan dan Filesystem';
$text['mount']          = 'Titik Mount';
$text['partition']      = 'Partisi';

$text['percent']        = 'Digunakan (Persen)';
$text['type']           = 'Tipe';
$text['free']           = 'Bebas';
$text['used']           = 'Digunakan';
$text['size']           = 'Ukuran';
$text['totals']         = 'Total';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'tidak ditemukan';

$text['capacity']       = 'Kapasitas'; 

$text['template']       = 'Template';
$text['language']       = 'Bahasa';
$text['submit']         = 'Gunakan';
$text['created']        = 'Dibangun menggunakan';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'hari';
$text['hours']          = 'jam';
$text['minutes']        = 'menit';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/id.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: id.php,v 1.16 2006/06/05 11:48:16 bigmichi1 Exp $
// Translated by: Firman Pribadi <http://ragiel.dhs.org>

$text['title']          = 'Informasi Sistem';

$text['vitals']         = 'Informasi Utama';
$text['hostname']       = 'Hostname Resmi';
$text['ip']             = 'IP Penerima';
$text['kversion']       = 'Versi Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Aktif Selama';
$text['users']          = 'Pengguna Saat Ini';
$text['loadavg']        = 'Beban Rata-rata';

$text['hardware']       = 'Informasi Perangkat Keras';
$text['numcpu']         = 'Prosesor';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Ukuran Cache';
$text['bogomips']       = 'Sistem Bogomips';

$text['pci']            = 'Perangkat PCI';
$text['ide']            = 'Perangkat IDE';
$text['scsi']           = 'Perangkat SCSI';
$text['usb']            = 'Perangkat USB';

$text['netusage']       = 'Status Penggunaan Jaringan';
$text['device']         = 'Perangkat';
$text['received']       = 'Diterima';
$text['sent']           = 'Dikirim';
$text['errors']         = 'Rusak/Drop';

$text['connections']    = 'Koneksi Jaringan Aktif';

$text['memusage']       = 'Status Penggunaan Memori';
$text['phymem']         = 'Memori Fisik';
$text['swap']           = 'Swap HardDisk';

$text['fs']             = 'Status Penggunaan Media Penyimpanan dan Filesystem';
$text['mount']          = 'Titik Mount';
$text['partition']      = 'Partisi';

$text['percent']        = 'Digunakan (Persen)';
$text['type']           = 'Tipe';
$text['free']           = 'Bebas';
$text['used']           = 'Digunakan';
$text['size']           = 'Ukuran';
$text['totals']         = 'Total';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'tidak ditemukan';

$text['capacity']       = 'Kapasitas'; 

$text['template']       = 'Template';
$text['language']       = 'Bahasa';
$text['submit']         = 'Gunakan';
$text['created']        = 'Dibangun menggunakan';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'hari';
$text['hours']          = 'jam';
$text['minutes']        = 'menit';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
